import * as React from 'react';
export declare type DefaultFieldValues = Record<string, unknown>;
export declare type FieldValue = any;
export declare type FieldValues = Record<string, FieldValue>;
export declare type Ref = any;
declare type Mode = keyof ValidationMode;
export declare type OnSubmit<Data extends FieldValues> = (data: Data, e: React.SyntheticEvent) => void | Promise<void>;
export interface ValidationMode {
    onBlur: 'onBlur';
    onChange: 'onChange';
    onSubmit: 'onSubmit';
}
export declare type SchemaValidateOptions = Partial<{
    strict: boolean;
    abortEarly: boolean;
    stripUnknown: boolean;
    recursive: boolean;
    context: object;
}>;
export interface Schema<Data> {
    validate(value: FieldValues, options?: SchemaValidateOptions): Promise<Data>;
}
export declare type Options<FormValues extends FieldValues = DefaultFieldValues, FieldName extends keyof FormValues = keyof FormValues> = Partial<{
    mode: Mode;
    defaultValues: Partial<FormValues>;
    validationSchemaOption: SchemaValidateOptions;
    validationFields: FieldName[];
    validationSchema: any;
    nativeValidation: boolean;
    submitFocusError: boolean;
}>;
export interface MutationWatcher {
    disconnect: VoidFunction;
    observe?: any;
}
declare type ValidationOptionObject<Value> = Value | {
    value: Value;
    message: string;
};
export declare type ValidationTypes = number | string | RegExp;
export declare type Validate = (data: FieldValue) => string | boolean | void;
export declare type ValidationOptions = Partial<{
    required: boolean | string;
    min: ValidationOptionObject<number | string>;
    max: ValidationOptionObject<number | string>;
    maxLength: ValidationOptionObject<number | string>;
    minLength: ValidationOptionObject<number | string>;
    pattern: ValidationOptionObject<RegExp>;
    validate: Validate | Record<string, Validate> | {
        value: Validate | Record<string, Validate>;
        message: string;
    };
}>;
export declare type ValidatePromiseResult = {} | void | {
    type: string;
    message: string | number | boolean | Date;
};
export interface Field extends ValidationOptions {
    ref: Ref;
    watch?: boolean;
    mutationWatcher?: MutationWatcher;
    options?: {
        ref: Ref;
        mutationWatcher?: MutationWatcher;
    }[];
}
export declare type FieldsRefs<Data extends FieldValues> = Partial<Record<keyof Data, Field>>;
export interface FieldError {
    ref: Ref;
    type: string;
    message?: string;
    isManual?: boolean;
}
export declare type FieldErrors<Data extends FieldValues> = Partial<Record<keyof Data, FieldError>>;
export interface SubmitPromiseResult<Data extends FieldValues> {
    errors: FieldErrors<Data>;
    values: Data;
}
export interface SchemaValidationResult<FormValues> {
    fieldErrors: FieldErrors<FormValues>;
    result: FieldValues;
}
export interface ValidationPayload<Name, Value> {
    name: Name;
    value?: Value;
}
export interface FormState<FormValues extends FieldValues = FieldValues, FieldName extends keyof FormValues = keyof FormValues> {
    dirty: boolean;
    isSubmitted: boolean;
    submitCount: number;
    touched: FieldName[];
    isSubmitting: boolean;
    isValid: boolean;
}
export interface ElementLike {
    name: string;
    type?: string;
    value?: string;
    checked?: boolean;
    options?: any;
}
export {};
